==> eaimxrt1062_4mb_sdk_2_12_1_2022-11-18.zip: middleware/maestro/docs/src/annotated_dup.js <==
var annotated_dup =
[
    [ "AlbumArt", "structAlbumArt.html", "structAlbumArt" ],
    [ "AudioPacketHeader", "structAudioPacketHeader.html", "structAudioPacketHeader" ],
    [ "AudioSinkPadDeviceIOFuncType", "structAudioSinkPadDeviceIOFuncType.html", "structAudioSinkPadDeviceIOFuncType" ],
    [ "AUDSRC_SET_NAME_T", "structAUDSRC__SET__NAME__T.html", "structAUDSRC__SET__NAME__T" ],
    [ "BufferInfo", "structBufferInfo.html", "structBufferInfo" ],
    [ "CCI_Ctx", "structCCI__Ctx.html", "structCCI__Ctx" ],
    [ "CCIDecInfo", "structCCIDecInfo.html", "structCCIDecInfo" ],
    [ "CeiBitstreamInfo", "structCeiBitstreamInfo.html", "structCeiBitstreamInfo" ],
    [ "CeiEncoderFunctions", "structCeiEncoderFunctions.html", "structCeiEncoderFunctions" ],
    [ "CeiOpusConfig", "structCeiOpusConfig.html", "structCeiOpusConfig" ],
    [ "codec_interface_function_table_t", "structcodec__interface__function__table__t.html", "structcodec__interface__function__table__t" ],
    [ "decoder_callback_FunctionTable_t", "structdecoder__callback__FunctionTable__t.html", "structdecoder__callback__FunctionTable__t" ],
    [ "DecoderHandlersType", "structDecoderHandlersType.html", "structDecoderHandlersType" ],
    [ "ELEMENT_PROPERTY_T", "structELEMENT__PROPERTY__T.html", "structELEMENT__PROPERTY__T" ],
    [ "ElementAudioSink", "struct__ElementAudioSink.html", "struct__ElementAudioSink" ],
    [ "ElementAudioSrc", "struct__ElementAudioSrc.html", "struct__ElementAudioSrc" ],
    [ "ElementDecoder", "struct__ElementDecoder.html", "struct__ElementDecoder" ],
    [ "ElementEap", "struct__ElementEap.html", "struct__ElementEap" ],
    [ "ElementEncoder", "structElementEncoder.html", "structElementEncoder" ],
    [ "ElementFileSink", "struct__ElementFileSink.html", "struct__ElementFileSink" ],
    [ "ElementFileSrc", "struct__ElementFileSrc.html", "struct__ElementFileSrc" ],
    [ "ElementInit", "structElementInit.html", "structElementInit" ],
    [ "ElementMemSink", "struct__ElementMemSink.html", "struct__ElementMemSink" ],
    [ "ElementMemSrc", "struct__ElementMemSrc.html", "struct__ElementMemSrc" ],
    [ "ElementNetbufSrc", "structElementNetbufSrc.html", "structElementNetbufSrc" ],
    [ "ElementPropertyLookup", "structElementPropertyLookup.html", "structElementPropertyLookup" ],
    [ "ElementVitSink", "struct__ElementVitSink.html", "struct__ElementVitSink" ],
    [ "ext_proc_args", "structext__proc__args.html", "structext__proc__args" ],
    [ "EXT_PROCESS_DESC_T", "structEXT__PROCESS__DESC__T.html", "structEXT__PROCESS__DESC__T" ],
    [ "File_Fs_Rec", "structFile__Fs__Rec.html", "structFile__Fs__Rec" ],
    [ "file_meta_data_t", "structfile__meta__data__t.html", "structfile__meta__data__t" ],
    [ "FileDump", "structFileDump.html", "structFileDump" ],
    [ "MEMSRC_SET_BUFFER_T", "structMEMSRC__SET__BUFFER__T.html", "structMEMSRC__SET__BUFFER__T" ],
    [ "PacketHeader", "structPacketHeader.html", "structPacketHeader" ],
    [ "PadSink", "struct__PadSink.html", "struct__PadSink" ],
    [ "PadSrc", "struct__PadSrc.html", "struct__PadSrc" ],
    [ "PCMRtosDeviceInfo", "structPCMRtosDeviceInfo.html", "structPCMRtosDeviceInfo" ],
    [ "PCMSinkDeviceInfo", "structPCMSinkDeviceInfo.html", "structPCMSinkDeviceInfo" ],
    [ "Pipeline", "struct__Pipeline.html", "struct__Pipeline" ],
    [ "QUEUE_SET_BUFFER_T", "structQUEUE__SET__BUFFER__T.html", "structQUEUE__SET__BUFFER__T" ],
    [ "RawPacketHeader", "structRawPacketHeader.html", "structRawPacketHeader" ],
    [ "ringbuf_t", "structringbuf.html", "structringbuf" ],
    [ "SET_BUFFER_DESC_T", "structSET__BUFFER__DESC__T.html", "structSET__BUFFER__DESC__T" ],
    [ "StreamBuffer", "structStreamBuffer.html", "structStreamBuffer" ],
    [ "StreamData", "unionStreamData.html", "unionStreamData" ],
    [ "StreamElement", "struct__StreamElement.html", "struct__StreamElement" ],
    [ "STREAMER_CREATE_PARAM", "structSTREAMER__CREATE__PARAM.html", "structSTREAMER__CREATE__PARAM" ],
    [ "STREAMER_MSG_HANDLER_T", "structSTREAMER__MSG__HANDLER__T.html", "structSTREAMER__MSG__HANDLER__T" ],
    [ "STREAMER_MSG_T", "structSTREAMER__MSG__T.html", "structSTREAMER__MSG__T" ],
    [ "STREAMER_T", "structSTREAMER__T.html", "structSTREAMER__T" ],
    [ "StreamerFileSrcConfig", "structStreamerFileSrcConfig.html", "structStreamerFileSrcConfig" ],
    [ "StreamEvent", "structStreamEvent.html", "structStreamEvent" ],
    [ "StreamImageType", "structStreamImageType.html", "structStreamImageType" ],
    [ "StreamMessage", "structStreamMessage.html", "structStreamMessage" ],
    [ "StreamPad", "struct__StreamPad.html", "struct__StreamPad" ],
    [ "StreamQuery", "structStreamQuery.html", "structStreamQuery" ],
    [ "StreamStringType", "structStreamStringType.html", "structStreamStringType" ],
    [ "STRING_DESC_T", "structSTRING__DESC__T.html", "structSTRING__DESC__T" ],
    [ "TrackInfo", "structTrackInfo.html", "structTrackInfo" ]
];

==> eaimxrt1062_16mb_sdk_2_15_000_2024-03-12.zip: middleware/maestro/docs/src/annotated_dup.js <==
var annotated_dup =
[
    [ "AlbumArt", "structAlbumArt.html", "structAlbumArt" ],
    [ "AudioPacketHeader", "structAudioPacketHeader.html", "structAudioPacketHeader" ],
    [ "AudioRefData_t", "structAudioRefData__t.html", "structAudioRefData__t" ],
    [ "AudioSinkPadDeviceIOFuncType", "structAudioSinkPadDeviceIOFuncType.html", "structAudioSinkPadDeviceIOFuncType" ],
    [ "AudioSrcBufferQueue_t", "structAudioSrcBufferQueue__t.html", "structAudioSrcBufferQueue__t" ],
    [ "AUDSRC_SET_NAME_T", "structAUDSRC__SET__NAME__T.html", "structAUDSRC__SET__NAME__T" ],
    [ "BufferInfo", "structBufferInfo.html", "structBufferInfo" ],
    [ "CCI_Ctx", "structCCI__Ctx.html", "structCCI__Ctx" ],
    [ "CCIDecInfo", "structCCIDecInfo.html", "structCCIDecInfo" ],
    [ "CeiBitstreamInfo", "structCeiBitstreamInfo.html", "structCeiBitstreamInfo" ],
    [ "CeiEncoderFunctions", "structCeiEncoderFunctions.html", "structCeiEncoderFunctions" ],
    [ "CeiOpusConfig", "structCeiOpusConfig.html", "structCeiOpusConfig" ],
    [ "codec_interface_function_table_t", "structcodec__interface__function__table__t.html", "structcodec__interface__function__table__t" ],
    [ "decoder_callback_FunctionTable_t", "structdecoder__callback__FunctionTable__t.html", "structdecoder__callback__FunctionTable__t" ],
    [ "DecoderHandlersType", "structDecoderHandlersType.html", "structDecoderHandlersType" ],
    [ "ELEMENT_PROPERTY_T", "structELEMENT__PROPERTY__T.html", "structELEMENT__PROPERTY__T" ],
    [ "ElementAudioProc", "struct__ElementAudioProc.html", "struct__ElementAudioProc" ],
    [ "ElementAudioSink", "struct__ElementAudioSink.html", "struct__ElementAudioSink" ],
    [ "ElementAudioSrc", "struct__ElementAudioSrc.html", "struct__ElementAudioSrc" ],
    [ "ElementDecoder", "struct__ElementDecoder.html", "struct__ElementDecoder" ],
    [ "ElementEncoder", "structElementEncoder.html", "structElementEncoder" ],
    [ "ElementFileSink", "struct__ElementFileSink.html", "struct__ElementFileSink" ],
    [ "ElementFileSrc", "struct__ElementFileSrc.html", "struct__ElementFileSrc" ],
    [ "ElementInit", "structElementInit.html", "structElementInit" ],
    [ "ElementMemSink", "struct__ElementMemSink.html", "struct__ElementMemSink" ],
    [ "ElementMemSrc", "struct__ElementMemSrc.html", "struct__ElementMemSrc" ],
    [ "ElementNetbufSrc", "structElementNetbufSrc.html", "structElementNetbufSrc" ],
    [ "ElementPropertyLookup", "structElementPropertyLookup.html", "structElementPropertyLookup" ],
    [ "ElementTypeLookup", "structElementTypeLookup.html", "structElementTypeLookup" ],
    [ "ElementVitSink", "struct__ElementVitSink.html", "struct__ElementVitSink" ],
    [ "EXT_AUDIOELEMENT_DESC_T", "structEXT__AUDIOELEMENT__DESC__T.html", "structEXT__AUDIOELEMENT__DESC__T" ],
    [ "ext_proc_args", "structext__proc__args.html", "structext__proc__args" ],
    [ "EXT_PROCESS_DESC_T", "structEXT__PROCESS__DESC__T.html", "structEXT__PROCESS__DESC__T" ],
    [ "EXT_PROCESS_REFDAT_DESC_T", "structEXT__PROCESS__REFDAT__DESC__T.html", "structEXT__PROCESS__REFDAT__DESC__T" ],
    [ "File_Fs_Rec", "structFile__Fs__Rec.html", "structFile__Fs__Rec" ],
    [ "file_meta_data_t", "structfile__meta__data__t.html", "structfile__meta__data__t" ],
    [ "FileDump", "structFileDump.html", "structFileDump" ],
    [ "LVM_BPMModuleStats_st", "structLVM__BPMModuleStats__st.html", "structLVM__BPMModuleStats__st" ],
    [ "LVM_ContextTable_st", "structLVM__ContextTable__st.html", "structLVM__ContextTable__st" ],
    [ "LVM_MemoryRegion_st", "structLVM__MemoryRegion__st.html", "structLVM__MemoryRegion__st" ],
    [ "LVM_MemoryTable_st", "structLVM__MemoryTable__st.html", "structLVM__MemoryTable__st" ],
    [ "MEMSRC_SET_BUFFER_T", "structMEMSRC__SET__BUFFER__T.html", "structMEMSRC__SET__BUFFER__T" ],
    [ "PacketHeader", "structPacketHeader.html", "structPacketHeader" ],
    [ "PadSink", "struct__PadSink.html", "struct__PadSink" ],
    [ "PadSrc", "struct__PadSrc.html", "struct__PadSrc" ],
    [ "PCMRtosDeviceInfo", "structPCMRtosDeviceInfo.html", "structPCMRtosDeviceInfo" ],
    [ "PCMSinkDeviceInfo", "structPCMSinkDeviceInfo.html", "structPCMSinkDeviceInfo" ],
    [ "Pipeline", "struct__Pipeline.html", "struct__Pipeline" ],
    [ "PipelineElements", "structPipelineElements.html", "structPipelineElements" ],
    [ "QUEUE_SET_BUFFER_T", "structQUEUE__SET__BUFFER__T.html", "structQUEUE__SET__BUFFER__T" ],
    [ "RawPacketHeader", "structRawPacketHeader.html", "structRawPacketHeader" ],
    [ "ringbuf_t", "structringbuf.html", "structringbuf" ],
    [ "SET_BUFFER_DESC_T", "structSET__BUFFER__DESC__T.html", "structSET__BUFFER__DESC__T" ],
    [ "SSRC_Instance_t", "structSSRC__Instance__t.html", "structSSRC__Instance__t" ],
    [ "SSRC_Params_t", "structSSRC__Params__t.html", "structSSRC__Params__t" ],
    [ "StreamBuffer", "structStreamBuffer.html", "structStreamBuffer" ],
    [ "StreamData", "unionStreamData.html", "unionStreamData" ],
    [ "StreamElement", "struct__StreamElement.html", "struct__StreamElement" ],
    [ "STREAMER_CREATE_PARAM", "structSTREAMER__CREATE__PARAM.html", "structSTREAMER__CREATE__PARAM" ],
    [ "STREAMER_MSG_HANDLER_T", "structSTREAMER__MSG__HANDLER__T.html", "structSTREAMER__MSG__HANDLER__T" ],
    [ "STREAMER_MSG_T", "structSTREAMER__MSG__T.html", "structSTREAMER__MSG__T" ],
    [ "STREAMER_T", "structSTREAMER__T.html", "structSTREAMER__T" ],
    [ "StreamerFileSrcConfig", "structStreamerFileSrcConfig.html", "structStreamerFileSrcConfig" ],
    [ "StreamEvent", "structStreamEvent.html", "structStreamEvent" ],
    [ "StreamImageType", "structStreamImageType.html", "structStreamImageType" ],
    [ "StreamMessage", "structStreamMessage.html", "structStreamMessage" ],
    [ "StreamPad", "struct__StreamPad.html", "struct__StreamPad" ],
    [ "StreamQuery", "structStreamQuery.html", "structStreamQuery" ],
    [ "StreamStringType", "structStreamStringType.html", "structStreamStringType" ],
    [ "STRING_DESC_T", "structSTRING__DESC__T.html", "structSTRING__DESC__T" ],
    [ "TrackInfo", "structTrackInfo.html", "structTrackInfo" ]
];
